## ----options, include=FALSE----------------------------------------------
library(knitr)
options(digits=3, width=80)
opts_chunk$set(echo=TRUE,tidy=FALSE,include=TRUE,
               dev='png', fig.width = 9, fig.height = 5.25, comment = '  ', dpi = 300,
cache = TRUE)

## ----required packages and data, echo = TRUE-----------------------------
library(knitr)
library(DChIPRep)
library(purrr)
library(BiocStyle)
library(ggplot2)
library(plyr)
library(dplyr)
library(RColorBrewer)
library(stringr)
library(pheatmap)
library(openxlsx)
library(devtools)
library(biomaRt)
library(tidyr)
library(csaw)
library(DESeq2)
library(edgeR)
library(fdrtool)
library(reshape2)
library(smoothmest)
library(gplots)
library(cowplot)

## ----caseStudy1----------------------------------------------------------
load("importedData.RData")

sampleTable_K4me2 <- read.csv("sampleTable_K4me2.csv")

## ----markupSampleTable, dependson="caseStudy1", markup="asis"------------
kable(sampleTable_K4me2, format = "html")

## ----caseStudy2, dependson="caseStudy1"----------------------------------

testDChIPRep <- runTesting(importedData, plotFDR = FALSE)
plotSignificance(testDChIPRep)

### Get the number of bases with significant changes
resDChIPRep <- resultsDChIPRep(testDChIPRep)

table(resDChIPRep$lfdr < 0.2)

lfdrDChIPRep <- resDChIPRep$lfdr[1001:2501]
sum(lfdrDChIPRep < 0.2)


## ----edgeRPipeline, dependson="caseStudy1", fig.width = 18---------------

# extract counts
ccc <- counts(DESeq2Data(importedData))


condition <- colData(DESeq2Data(importedData))$condition
y <- DGEList(ccc, 
             group = condition)

nf <- normalizationFactors(DESeq2Data(importedData))

y$offset <- log(nf)

design <- model.matrix(~ 0 +  condition)
colnames(design) <- levels(condition)
y <- estimateDisp(y, design = design)
plotBCV(y)
fit <- glmQLFit(y, design, robust=TRUE)
plotQLDisp(fit)

contrast <- makeContrasts(WT-mutant, levels=design)
res <- glmQLFTest(fit, contrast=contrast)

resEdgeR <- topTags(sort.by = "none", res, n=Inf)$table

FDRedgeR <- fdrtool(resEdgeR$PValue, statistic = "pvalue", plot = FALSE)
resEdgeR$ldfr <- FDRedgeR$lfdr

table(resEdgeR$ldfr < 0.2)

lfdrEdgeR <- FDRedgeR$lfdr[1001:2501]
sum(lfdrEdgeR < 0.2)



countsLog2 <- as.data.frame(log2(counts(DESeq2Data(importedData), norm = TRUE)))


sampleTable <- colData(DESeq2Data(importedData))

pos <-   seq(from =-unique(sampleTable$upstream)
                            , to = unique(sampleTable$downstream), by = 1)

suppressMessages(c.ggplot2 <- data.frame(pos = pos,
                        melt(countsLog2,
                                       variable.name= "sample",
                                       value.name= "PosSignal")))

### get mean per group for ratio plots
m.f <- function(x) { smhuber(x)$mu }
m.per.group <- t(aggregate.data.frame(t(countsLog2),
                                      by = list(sampleTable$condition), FUN = m.f )[,-1])
colnames(m.per.group) <-  levels(sampleTable$condition)


# introduce post hoc l2fc cutoff
idxSig <- resEdgeR$ldfr < 0.2 & (abs(resEdgeR$logFC / log(2)) > 0.05)

#idxSig <- resEdgeR$FDR < 0.05 & (abs(resEdgeR$logFC / log(2)) > 0.05)

m.per.group <- as.data.frame(m.per.group)
m.per.group$pos <- pos
m.per.group$significant <- idxSig

dataGG <- gather(m.per.group,
       key = "experimental_Group_and_significance",
       value = "mean_log2_counts", 1:2)

dataGG$experimental_Group_and_significance <- ifelse(dataGG$significant,
                                                      "significant",
                                                     as.character(dataGG$experimental_Group_and_significance))

dataGG$experimental_Group_and_significance  <- mapvalues(dataGG$experimental_Group_and_significance,
          from = c("mutant", "WT", "significant"), to = c("Mutant", "Wild type", "Significant Difference"))

dataGG$experimental_Group_and_significance <- factor(dataGG$experimental_Group_and_significance,
                                                     levels = c("Mutant", "Wild type", "Significant Difference"))

pl <- (ggplot(data = dataGG, 
              aes_string(x = "pos",
                         y = "mean_log2_counts",
                         color = "experimental_Group_and_significance")) +
      geom_point() +
      labs(x ="Distance from TSS (bp)",
           y="Normalized counts (log2)") +
      scale_color_manual(values = c( "#d95f02", "#7570b3", "black"), name = "") +
      theme(panel.background = element_blank(), panel.grid.minor=element_blank(),
      axis.line = element_line(colour = "black", size = 0.5)))




pl <- (pl + theme( axis.ticks.length = unit(10, "points"),
             axis.line = element_line(size = 1),
              axis.title = element_text(size = 16, face = "bold"),
             axis.text = element_text(size = 12, face = "bold"),
             plot.title = element_text(size = 16, face = "bold"),
             legend.position = c(0.4, .7),
             legend.key = element_rect(fill = "white"),
             legend.text = element_text(size = 16, face = "bold")
            )
+ ggtitle("Significantly enriched regions based on csaw/edgeR"))


# add previous results as an additional panel

DChIPRepPlot <- (plotSignificance(testDChIPRep) 
            + theme( axis.ticks.length = unit(10, "points"),
             axis.line = element_line(size = 1),
              axis.title = element_text(size = 16, face = "bold"),
             axis.text = element_text(size = 12, face = "bold"),
             plot.title = element_text(size = 16, face = "bold"),
             legend.position = c(0.4, .7),
             legend.key = element_rect(fill = "white"),
             legend.text = element_text(size = 16, face = "bold"),
             panel.background = element_blank(), panel.grid.minor=element_blank(),
            axis.line = element_line(colour = "black", size = 0.5)
            )
            + labs(x ="Distance from TSS (bp)",
           y="Normalized counts (log2)")
           + guides(color = guide_legend(title = NULL))
           +  ggtitle("Significantly enriched regions based on DChIPRep")
           + scale_color_manual(values = c("#3366CC", "#e41a1c", "black"), 
                                labels = c("Mutant", "Wild type", "Significant Difference")))
    
               
#svg(filename = 'K4me2_significance_edgeR.svg',height = 6, width = 15)
plot_grid(DChIPRepPlot, pl, labels = c("A", "B"), ncol = 2, align = "h")
#dev.off()

## ----overlap_deseq_edger-------------------------------------------------

positions <- rownames(DESeq2Data(testDChIPRep))[1001:2501]

DESeq <- positions[lfdrDChIPRep < 0.2]
edgeR <- positions[lfdrEdgeR < 0.2]

ll <- list(DESeq, edgeR )

venn(ll)

#venn.diagram(ll, filename = "test.tiff", category.names = c("A", "B"))

#how many positions up to 250 bp downstream are shared?
table(as.integer(str_replace(intersect(DESeq[1:500],
                                       edgeR[1:500]), "Pos_", "")) < 250)

# only 1% (5)!

## ----importGalonska------------------------------------------------------
load("galonskaData.rda")

sample_table_galonska


## ----galonskaFigure------------------------------------------------------

DChIPRep_galonska <- importDataFromMatrices(input_galonska, 
                                            chip_galonska, 
                                            sample_table_galonska)

plotProfiles(DChIPRep_galonska)


DChIPRep_galonska  <- runTesting(DChIPRep_galonska, lfcThreshold = 0.00, plotFDR = TRUE)


res_galonska <- resultsDChIPRep(DChIPRep_galonska)

table(res_galonska$lfdr < 0.3)

pl_galonksa <- plotSignificance(DChIPRep_galonska, lfdrThresh = 0.3)


pl_galonksa <- (pl_galonksa  + theme( axis.ticks.length = unit(10, "points"),
             axis.line = element_line(size = 1),
              axis.title = element_text(size = 16, face = "bold"),
             axis.text = element_text(size = 12, face = "bold"),
             plot.title = element_text(size = 16, face = "bold"),
             legend.position = c(0.55, .42),
             legend.key = element_rect(fill = "white"),
             legend.text = element_text(size = 16, face = "bold"),
             panel.background = element_blank(), panel.grid.minor=element_blank(),
            axis.line = element_line(colour = "black", size = 0.5))
          
            + scale_color_manual(values = c( "#36B522", "#D06EE6", "grey40"), guide = 
                                   guide_legend(title = NULL)) 
            + labs(y="Normalized counts (log2)")
            + ggtitle("Significantly enriched regions for the H3K4me3 data from Galonska et. al."))
#svg(filename = 'H3K4me3_golonska.svg',height = 6, width = 15)
pl_galonksa  
#dev.off()        


## ----sessionInfo, cache = FALSE------------------------------------------
sessionInfo()

